from enum import Enum

class TravelType(Enum):
    CAR = "car"
    WALK = "walk"
    BIKE = "bike"
    TRANSIT = "transit"

    @classmethod
    def parse(clazz, str):

        if str is None:
            raise Exception('Travel type: "None" not supported!')

        type = getattr(clazz, str.upper(), None)
        if type is None:
            raise Exception('Travel type: "' + str + '" not supported!')

        return type


class Configuration:
    'This class represents a single configuration, build from traveloptions, for a request'

    @staticmethod
    def build(travelOptions):
        cfg = {
            "sources": travelOptions.getSources()
        }

        if travelOptions.getTravelTimes():
            polygonJson = {
              "values": travelOptions.getTravelTimes(),
              "intersectionMode": travelOptions.getPolygonIntersectionMode().value,
              "serializer": travelOptions.getPolygonSerializationType().value,
              "pointReduction": True,
              "minPolygonHoleSize": travelOptions.getMinPolygonHoleSize()
            }

            if not travelOptions.getBuffer() is None:
                polygonJson['buffer'] = travelOptions.getBuffer();
            if not travelOptions.getSimplifyMeter() is None:
                polygonJson['simplify'] = travelOptions.getSimplifyMeter();
            if not travelOptions.getSrid() is None:
                polygonJson['srid'] = travelOptions.getSrid();
            if not travelOptions.getQuadrantSegments() is None:
                polygonJson['quadrantSegments'] = travelOptions.getQuadrantSegments();

            cfg['polygon'] = polygonJson

        if not travelOptions.getPathSerializer() is None:
            cfg['pathSerializer'] = travelOptions.getPathSerializer().value

        if travelOptions.getTargets():
            cfg['targets'] = travelOptions.getTargets()

        if not travelOptions.getEdgeWeightType() is None:
            cfg['edgeWeightType'] = travelOptions.getEdgeWeightType().value

        return cfg



from enum import Enum


class PathSerializerType(Enum):
    COMPACT_PATH_SERIALIZER = "compact"
    GEO_JSON_PATH_SERIALIZER = "geojson"

    @classmethod
    def parse(cls, str):
        return getattr(cls, str.upper(), None)



from enum import Enum


class EdgeWeightType(Enum):
    DISTANCE = "distance"
    TIME = "time"

    @classmethod
    def parse(cls, str_to_parse):
        return getattr(cls, str_to_parse.upper(), None)



import datetime
import math

class Util:
    'This class encapsulates generaly usefull methods from all sorts of domains'

    @staticmethod
    def currentDate():
        return datetime.datetime.now().strftime("%Y%m%d")

    @staticmethod
    def currentTime():

        now = datetime.datetime.now()
        seconds_since_midnight = (now - now.replace(hour=0, minute=0, second=0, microsecond=0)).total_seconds()
        return int(math.ceil(seconds_since_midnight / 60.0)) * 60